Crossbar.io FX Database
=======================

| |Travis|

**cfxdb** is a CrossbarFX Python support package with core database access classes
written in native Python. The package allows direct in-memory data access from
Python programs (including Jupyter notebooks) to CrossbarFX edge node data:

* persisted WAMP event history
* persisted router tracing data
* XBR market maker transactions database
* XBR network backend database
* WAMP session cache

--------------

*Copyright (C) 2018-2020 Crossbar.io Technologies GmbH. All rights reserved.
WAMP, Crossbar.io and XBR are trademarks of Crossbar.io Technologies GmbH.*

.. |Travis| image:: https://api.travis-ci.com/crossbario/cfxdb.svg?branch=master
   :target: https://travis-ci.com/crossbario/cfxdb
